@@ -152,6 +152,8 @@
 ( cd opt/kde/share/doc/HTML/de/kverbos ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kweather ; ln -sf /opt/kde/share/doc/HTML/de/common common )
+( cd opt/kde/share/doc/HTML/de/kwuftpd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/de/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/de/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/de/common common )
 ( cd opt/kde/share/doc/HTML/de/kmenuedit ; rm -rf common )
